==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/analysis/ActiveUseTag.h <==
// public class org.dellroad.jc.cgen.analysis.ActiveUseTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a6feee12b4c8e105 org_dellroad_jc_cgen_analysis_ActiveUseTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_analysis_ActiveUseTag_H_
#define _JC_org_dellroad_jc_cgen_analysis_ActiveUseTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$sub_refs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$sub_nonrefs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$refs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$nonrefs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object;

typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$fields_struct	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$fields_struct;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vmethods	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vtable	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vtype	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vtype;

// Class fields structure
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$fields_struct {
	struct _jc_java_lang_String$object	*NAME;
	struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object	*NEEDED;
	struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object	*NOT__5fNEEDED;
};
extern _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$fields_struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$class_fields;

// Constructors
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$method$_init$f0a6314ff7de5110(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object *, jboolean);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object *);
extern _jc_byte_array *_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object *);
extern jboolean _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$method$isCheckNeeded$fe6db5f9a8c2fb59(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object *);
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$method_info$isCheckNeeded$fe6db5f9a8c2fb59;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object *_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$method$v$d6a59c46796ff988(_jc_env *, jboolean);

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object *);
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object *);
	jboolean	(*isCheckNeeded$fe6db5f9a8c2fb59)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object *);
};

// Vtable
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vmethods	org_dellroad_jc_cgen_analysis_ActiveUseTag;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$refs {
    _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$sub_refs	org_dellroad_jc_cgen_analysis_ActiveUseTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$sub_nonrefs {
	jboolean	checkNeeded;
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$sub_nonrefs	org_dellroad_jc_cgen_analysis_ActiveUseTag;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object {
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vtype _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_analysis_ActiveUseTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_analysis_ActiveUseTag_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/analysis/ActiveUseTag.h <==
// public class org.dellroad.jc.cgen.analysis.ActiveUseTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a6feee12b4c8e105 org_dellroad_jc_cgen_analysis_ActiveUseTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_analysis_ActiveUseTag_H_
#define _JC_org_dellroad_jc_cgen_analysis_ActiveUseTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$sub_refs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$sub_nonrefs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$refs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$nonrefs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object;

typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$fields_struct	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$fields_struct;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vmethods	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vtable	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vtype	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vtype;

// Class fields structure
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$fields_struct {
	struct _jc_java_lang_String$object	*NAME;
	struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object	*NEEDED;
	struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object	*NOT__5fNEEDED;
};
extern _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$fields_struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$class_fields;

// Constructors
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$method$_init$f0a6314ff7de5110(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object *) _JC_JCNI_ATTR;
extern jboolean _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$method$isCheckNeeded$fe6db5f9a8c2fb59(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$method_info$isCheckNeeded$fe6db5f9a8c2fb59;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object *_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$method$v$d6a59c46796ff988(_jc_env *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object *) _JC_JCNI_ATTR;
	jboolean	(*isCheckNeeded$fe6db5f9a8c2fb59)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vmethods	org_dellroad_jc_cgen_analysis_ActiveUseTag;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$refs {
    _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$sub_refs	org_dellroad_jc_cgen_analysis_ActiveUseTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$sub_nonrefs {
	jboolean	checkNeeded;
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$sub_nonrefs	org_dellroad_jc_cgen_analysis_ActiveUseTag;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$object {
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$vtype _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_analysis_ActiveUseTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_analysis_ActiveUseTag$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_analysis_ActiveUseTag_H_ */
